# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Topic(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Topic - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'published': 'bool',
            'strictness': 'str',
            'programs': 'list[BaseProgramEntity]',
            'tags': 'list[str]',
            'dialect': 'str',
            'participants': 'str',
            'phrases': 'list[Phrase]',
            'modified_by': 'AddressableEntityRef',
            'date_modified': 'datetime',
            'published_by': 'AddressableEntityRef',
            'date_published': 'datetime',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'published': 'published',
            'strictness': 'strictness',
            'programs': 'programs',
            'tags': 'tags',
            'dialect': 'dialect',
            'participants': 'participants',
            'phrases': 'phrases',
            'modified_by': 'modifiedBy',
            'date_modified': 'dateModified',
            'published_by': 'publishedBy',
            'date_published': 'datePublished',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._published = None
        self._strictness = None
        self._programs = None
        self._tags = None
        self._dialect = None
        self._participants = None
        self._phrases = None
        self._modified_by = None
        self._date_modified = None
        self._published_by = None
        self._date_published = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Topic.
        The globally unique identifier for the object.

        :return: The id of this Topic.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Topic.
        The globally unique identifier for the object.

        :param id: The id of this Topic.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Topic.


        :return: The name of this Topic.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Topic.


        :param name: The name of this Topic.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Topic.


        :return: The description of this Topic.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Topic.


        :param description: The description of this Topic.
        :type: str
        """
        
        self._description = description

    @property
    def published(self):
        """
        Gets the published of this Topic.


        :return: The published of this Topic.
        :rtype: bool
        """
        return self._published

    @published.setter
    def published(self, published):
        """
        Sets the published of this Topic.


        :param published: The published of this Topic.
        :type: bool
        """
        
        self._published = published

    @property
    def strictness(self):
        """
        Gets the strictness of this Topic.


        :return: The strictness of this Topic.
        :rtype: str
        """
        return self._strictness

    @strictness.setter
    def strictness(self, strictness):
        """
        Sets the strictness of this Topic.


        :param strictness: The strictness of this Topic.
        :type: str
        """
        allowed_values = ["1", "55", "65", "72", "85", "90"]
        if strictness.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for strictness -> " + strictness)
            self._strictness = "outdated_sdk_version"
        else:
            self._strictness = strictness

    @property
    def programs(self):
        """
        Gets the programs of this Topic.


        :return: The programs of this Topic.
        :rtype: list[BaseProgramEntity]
        """
        return self._programs

    @programs.setter
    def programs(self, programs):
        """
        Sets the programs of this Topic.


        :param programs: The programs of this Topic.
        :type: list[BaseProgramEntity]
        """
        
        self._programs = programs

    @property
    def tags(self):
        """
        Gets the tags of this Topic.


        :return: The tags of this Topic.
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this Topic.


        :param tags: The tags of this Topic.
        :type: list[str]
        """
        
        self._tags = tags

    @property
    def dialect(self):
        """
        Gets the dialect of this Topic.


        :return: The dialect of this Topic.
        :rtype: str
        """
        return self._dialect

    @dialect.setter
    def dialect(self, dialect):
        """
        Sets the dialect of this Topic.


        :param dialect: The dialect of this Topic.
        :type: str
        """
        
        self._dialect = dialect

    @property
    def participants(self):
        """
        Gets the participants of this Topic.


        :return: The participants of this Topic.
        :rtype: str
        """
        return self._participants

    @participants.setter
    def participants(self, participants):
        """
        Sets the participants of this Topic.


        :param participants: The participants of this Topic.
        :type: str
        """
        allowed_values = ["External", "Internal", "All"]
        if participants.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for participants -> " + participants)
            self._participants = "outdated_sdk_version"
        else:
            self._participants = participants

    @property
    def phrases(self):
        """
        Gets the phrases of this Topic.


        :return: The phrases of this Topic.
        :rtype: list[Phrase]
        """
        return self._phrases

    @phrases.setter
    def phrases(self, phrases):
        """
        Sets the phrases of this Topic.


        :param phrases: The phrases of this Topic.
        :type: list[Phrase]
        """
        
        self._phrases = phrases

    @property
    def modified_by(self):
        """
        Gets the modified_by of this Topic.


        :return: The modified_by of this Topic.
        :rtype: AddressableEntityRef
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this Topic.


        :param modified_by: The modified_by of this Topic.
        :type: AddressableEntityRef
        """
        
        self._modified_by = modified_by

    @property
    def date_modified(self):
        """
        Gets the date_modified of this Topic.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this Topic.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this Topic.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this Topic.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def published_by(self):
        """
        Gets the published_by of this Topic.


        :return: The published_by of this Topic.
        :rtype: AddressableEntityRef
        """
        return self._published_by

    @published_by.setter
    def published_by(self, published_by):
        """
        Sets the published_by of this Topic.


        :param published_by: The published_by of this Topic.
        :type: AddressableEntityRef
        """
        
        self._published_by = published_by

    @property
    def date_published(self):
        """
        Gets the date_published of this Topic.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_published of this Topic.
        :rtype: datetime
        """
        return self._date_published

    @date_published.setter
    def date_published(self, date_published):
        """
        Sets the date_published of this Topic.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_published: The date_published of this Topic.
        :type: datetime
        """
        
        self._date_published = date_published

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Topic.
        The URI for this object

        :return: The self_uri of this Topic.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Topic.
        The URI for this object

        :param self_uri: The self_uri of this Topic.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ScimConfigResourceType(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ScimConfigResourceType - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'schemas': 'list[str]',
            'name': 'str',
            'description': 'str',
            'schema': 'str',
            'schema_extensions': 'list[ScimConfigResourceTypeSchemaExtension]',
            'endpoint': 'str',
            'meta': 'ScimMetadata'
        }

        self.attribute_map = {
            'id': 'id',
            'schemas': 'schemas',
            'name': 'name',
            'description': 'description',
            'schema': 'schema',
            'schema_extensions': 'schemaExtensions',
            'endpoint': 'endpoint',
            'meta': 'meta'
        }

        self._id = None
        self._schemas = None
        self._name = None
        self._description = None
        self._schema = None
        self._schema_extensions = None
        self._endpoint = None
        self._meta = None

    @property
    def id(self):
        """
        Gets the id of this ScimConfigResourceType.
        The ID of the SCIM resource. Set by the service provider. \"caseExact\" is set to \"true\". \"mutability\" is set to \"readOnly\". \"returned\" is set to \"always\".

        :return: The id of this ScimConfigResourceType.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ScimConfigResourceType.
        The ID of the SCIM resource. Set by the service provider. \"caseExact\" is set to \"true\". \"mutability\" is set to \"readOnly\". \"returned\" is set to \"always\".

        :param id: The id of this ScimConfigResourceType.
        :type: str
        """
        
        self._id = id

    @property
    def schemas(self):
        """
        Gets the schemas of this ScimConfigResourceType.
        The list of supported schemas.

        :return: The schemas of this ScimConfigResourceType.
        :rtype: list[str]
        """
        return self._schemas

    @schemas.setter
    def schemas(self, schemas):
        """
        Sets the schemas of this ScimConfigResourceType.
        The list of supported schemas.

        :param schemas: The schemas of this ScimConfigResourceType.
        :type: list[str]
        """
        
        self._schemas = schemas

    @property
    def name(self):
        """
        Gets the name of this ScimConfigResourceType.
        The name of the resource type.

        :return: The name of this ScimConfigResourceType.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ScimConfigResourceType.
        The name of the resource type.

        :param name: The name of this ScimConfigResourceType.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this ScimConfigResourceType.
        The description of the resource type.

        :return: The description of this ScimConfigResourceType.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ScimConfigResourceType.
        The description of the resource type.

        :param description: The description of this ScimConfigResourceType.
        :type: str
        """
        
        self._description = description

    @property
    def schema(self):
        """
        Gets the schema of this ScimConfigResourceType.
        The URI of the primary or base schema for the resource type.

        :return: The schema of this ScimConfigResourceType.
        :rtype: str
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """
        Sets the schema of this ScimConfigResourceType.
        The URI of the primary or base schema for the resource type.

        :param schema: The schema of this ScimConfigResourceType.
        :type: str
        """
        
        self._schema = schema

    @property
    def schema_extensions(self):
        """
        Gets the schema_extensions of this ScimConfigResourceType.
        The list of schema extensions for the resource type.

        :return: The schema_extensions of this ScimConfigResourceType.
        :rtype: list[ScimConfigResourceTypeSchemaExtension]
        """
        return self._schema_extensions

    @schema_extensions.setter
    def schema_extensions(self, schema_extensions):
        """
        Sets the schema_extensions of this ScimConfigResourceType.
        The list of schema extensions for the resource type.

        :param schema_extensions: The schema_extensions of this ScimConfigResourceType.
        :type: list[ScimConfigResourceTypeSchemaExtension]
        """
        
        self._schema_extensions = schema_extensions

    @property
    def endpoint(self):
        """
        Gets the endpoint of this ScimConfigResourceType.
        The HTTP-addressable endpoint of the resource type. Appears after the base URL.

        :return: The endpoint of this ScimConfigResourceType.
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """
        Sets the endpoint of this ScimConfigResourceType.
        The HTTP-addressable endpoint of the resource type. Appears after the base URL.

        :param endpoint: The endpoint of this ScimConfigResourceType.
        :type: str
        """
        
        self._endpoint = endpoint

    @property
    def meta(self):
        """
        Gets the meta of this ScimConfigResourceType.
        The metadata of the SCIM resource. Only \"location\" and \"resourceType\" are set for \"ResourceType\" resources.

        :return: The meta of this ScimConfigResourceType.
        :rtype: ScimMetadata
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """
        Sets the meta of this ScimConfigResourceType.
        The metadata of the SCIM resource. Only \"location\" and \"resourceType\" are set for \"ResourceType\" resources.

        :param meta: The meta of this ScimConfigResourceType.
        :type: ScimMetadata
        """
        
        self._meta = meta

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class BuManagementUnitScheduleSummary(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        BuManagementUnitScheduleSummary - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'management_unit': 'ManagementUnitReference',
            'agent_count': 'int',
            'start_date': 'datetime',
            'end_date': 'datetime',
            'agents': 'list[UserReference]'
        }

        self.attribute_map = {
            'management_unit': 'managementUnit',
            'agent_count': 'agentCount',
            'start_date': 'startDate',
            'end_date': 'endDate',
            'agents': 'agents'
        }

        self._management_unit = None
        self._agent_count = None
        self._start_date = None
        self._end_date = None
        self._agents = None

    @property
    def management_unit(self):
        """
        Gets the management_unit of this BuManagementUnitScheduleSummary.
        The management unit to which this summary applies

        :return: The management_unit of this BuManagementUnitScheduleSummary.
        :rtype: ManagementUnitReference
        """
        return self._management_unit

    @management_unit.setter
    def management_unit(self, management_unit):
        """
        Sets the management_unit of this BuManagementUnitScheduleSummary.
        The management unit to which this summary applies

        :param management_unit: The management_unit of this BuManagementUnitScheduleSummary.
        :type: ManagementUnitReference
        """
        
        self._management_unit = management_unit

    @property
    def agent_count(self):
        """
        Gets the agent_count of this BuManagementUnitScheduleSummary.
        The number of agents from this management unit that are in the schedule

        :return: The agent_count of this BuManagementUnitScheduleSummary.
        :rtype: int
        """
        return self._agent_count

    @agent_count.setter
    def agent_count(self, agent_count):
        """
        Sets the agent_count of this BuManagementUnitScheduleSummary.
        The number of agents from this management unit that are in the schedule

        :param agent_count: The agent_count of this BuManagementUnitScheduleSummary.
        :type: int
        """
        
        self._agent_count = agent_count

    @property
    def start_date(self):
        """
        Gets the start_date of this BuManagementUnitScheduleSummary.
        The start of the schedule change in the management unit. Only populated in schedule update notifications. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_date of this BuManagementUnitScheduleSummary.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this BuManagementUnitScheduleSummary.
        The start of the schedule change in the management unit. Only populated in schedule update notifications. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_date: The start_date of this BuManagementUnitScheduleSummary.
        :type: datetime
        """
        
        self._start_date = start_date

    @property
    def end_date(self):
        """
        Gets the end_date of this BuManagementUnitScheduleSummary.
        The end of the schedule change in the management unit. Only populated in schedule update notifications. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The end_date of this BuManagementUnitScheduleSummary.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this BuManagementUnitScheduleSummary.
        The end of the schedule change in the management unit. Only populated in schedule update notifications. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param end_date: The end_date of this BuManagementUnitScheduleSummary.
        :type: datetime
        """
        
        self._end_date = end_date

    @property
    def agents(self):
        """
        Gets the agents of this BuManagementUnitScheduleSummary.
        The agents in the management unit who are part of this schedule, or in schedule change notifications, the agents that were changed. Note this will come back as an empty list unless the appropriate expand query parameter is passed

        :return: The agents of this BuManagementUnitScheduleSummary.
        :rtype: list[UserReference]
        """
        return self._agents

    @agents.setter
    def agents(self, agents):
        """
        Sets the agents of this BuManagementUnitScheduleSummary.
        The agents in the management unit who are part of this schedule, or in schedule change notifications, the agents that were changed. Note this will come back as an empty list unless the appropriate expand query parameter is passed

        :param agents: The agents of this BuManagementUnitScheduleSummary.
        :type: list[UserReference]
        """
        
        self._agents = agents

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class UserConversationsEventUserConversationSummary(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UserConversationsEventUserConversationSummary - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'user_id': 'str',
            'call': 'UserConversationsEventMediaSummary',
            'callback': 'UserConversationsEventMediaSummary',
            'email': 'UserConversationsEventMediaSummary',
            'message': 'UserConversationsEventMediaSummary',
            'chat': 'UserConversationsEventMediaSummary',
            'social_expression': 'UserConversationsEventMediaSummary',
            'video': 'UserConversationsEventMediaSummary'
        }

        self.attribute_map = {
            'user_id': 'userId',
            'call': 'call',
            'callback': 'callback',
            'email': 'email',
            'message': 'message',
            'chat': 'chat',
            'social_expression': 'socialExpression',
            'video': 'video'
        }

        self._user_id = None
        self._call = None
        self._callback = None
        self._email = None
        self._message = None
        self._chat = None
        self._social_expression = None
        self._video = None

    @property
    def user_id(self):
        """
        Gets the user_id of this UserConversationsEventUserConversationSummary.


        :return: The user_id of this UserConversationsEventUserConversationSummary.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this UserConversationsEventUserConversationSummary.


        :param user_id: The user_id of this UserConversationsEventUserConversationSummary.
        :type: str
        """
        
        self._user_id = user_id

    @property
    def call(self):
        """
        Gets the call of this UserConversationsEventUserConversationSummary.


        :return: The call of this UserConversationsEventUserConversationSummary.
        :rtype: UserConversationsEventMediaSummary
        """
        return self._call

    @call.setter
    def call(self, call):
        """
        Sets the call of this UserConversationsEventUserConversationSummary.


        :param call: The call of this UserConversationsEventUserConversationSummary.
        :type: UserConversationsEventMediaSummary
        """
        
        self._call = call

    @property
    def callback(self):
        """
        Gets the callback of this UserConversationsEventUserConversationSummary.


        :return: The callback of this UserConversationsEventUserConversationSummary.
        :rtype: UserConversationsEventMediaSummary
        """
        return self._callback

    @callback.setter
    def callback(self, callback):
        """
        Sets the callback of this UserConversationsEventUserConversationSummary.


        :param callback: The callback of this UserConversationsEventUserConversationSummary.
        :type: UserConversationsEventMediaSummary
        """
        
        self._callback = callback

    @property
    def email(self):
        """
        Gets the email of this UserConversationsEventUserConversationSummary.


        :return: The email of this UserConversationsEventUserConversationSummary.
        :rtype: UserConversationsEventMediaSummary
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this UserConversationsEventUserConversationSummary.


        :param email: The email of this UserConversationsEventUserConversationSummary.
        :type: UserConversationsEventMediaSummary
        """
        
        self._email = email

    @property
    def message(self):
        """
        Gets the message of this UserConversationsEventUserConversationSummary.


        :return: The message of this UserConversationsEventUserConversationSummary.
        :rtype: UserConversationsEventMediaSummary
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this UserConversationsEventUserConversationSummary.


        :param message: The message of this UserConversationsEventUserConversationSummary.
        :type: UserConversationsEventMediaSummary
        """
        
        self._message = message

    @property
    def chat(self):
        """
        Gets the chat of this UserConversationsEventUserConversationSummary.


        :return: The chat of this UserConversationsEventUserConversationSummary.
        :rtype: UserConversationsEventMediaSummary
        """
        return self._chat

    @chat.setter
    def chat(self, chat):
        """
        Sets the chat of this UserConversationsEventUserConversationSummary.


        :param chat: The chat of this UserConversationsEventUserConversationSummary.
        :type: UserConversationsEventMediaSummary
        """
        
        self._chat = chat

    @property
    def social_expression(self):
        """
        Gets the social_expression of this UserConversationsEventUserConversationSummary.


        :return: The social_expression of this UserConversationsEventUserConversationSummary.
        :rtype: UserConversationsEventMediaSummary
        """
        return self._social_expression

    @social_expression.setter
    def social_expression(self, social_expression):
        """
        Sets the social_expression of this UserConversationsEventUserConversationSummary.


        :param social_expression: The social_expression of this UserConversationsEventUserConversationSummary.
        :type: UserConversationsEventMediaSummary
        """
        
        self._social_expression = social_expression

    @property
    def video(self):
        """
        Gets the video of this UserConversationsEventUserConversationSummary.


        :return: The video of this UserConversationsEventUserConversationSummary.
        :rtype: UserConversationsEventMediaSummary
        """
        return self._video

    @video.setter
    def video(self, video):
        """
        Sets the video of this UserConversationsEventUserConversationSummary.


        :param video: The video of this UserConversationsEventUserConversationSummary.
        :type: UserConversationsEventMediaSummary
        """
        
        self._video = video

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DialerRulesetConfigChangeRule(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DialerRulesetConfigChangeRule - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'order': 'int',
            'category': 'str',
            'actions': 'list[DialerRulesetConfigChangeAction]',
            'conditions': 'list[DialerRulesetConfigChangeCondition]',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'order': 'order',
            'category': 'category',
            'actions': 'actions',
            'conditions': 'conditions',
            'additional_properties': 'additionalProperties'
        }

        self._id = None
        self._name = None
        self._order = None
        self._category = None
        self._actions = None
        self._conditions = None
        self._additional_properties = None

    @property
    def id(self):
        """
        Gets the id of this DialerRulesetConfigChangeRule.


        :return: The id of this DialerRulesetConfigChangeRule.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DialerRulesetConfigChangeRule.


        :param id: The id of this DialerRulesetConfigChangeRule.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DialerRulesetConfigChangeRule.


        :return: The name of this DialerRulesetConfigChangeRule.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DialerRulesetConfigChangeRule.


        :param name: The name of this DialerRulesetConfigChangeRule.
        :type: str
        """
        
        self._name = name

    @property
    def order(self):
        """
        Gets the order of this DialerRulesetConfigChangeRule.


        :return: The order of this DialerRulesetConfigChangeRule.
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """
        Sets the order of this DialerRulesetConfigChangeRule.


        :param order: The order of this DialerRulesetConfigChangeRule.
        :type: int
        """
        
        self._order = order

    @property
    def category(self):
        """
        Gets the category of this DialerRulesetConfigChangeRule.


        :return: The category of this DialerRulesetConfigChangeRule.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this DialerRulesetConfigChangeRule.


        :param category: The category of this DialerRulesetConfigChangeRule.
        :type: str
        """
        allowed_values = ["DIALER_PRECALL", "DIALER_WRAPUP"]
        if category.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for category -> " + category)
            self._category = "outdated_sdk_version"
        else:
            self._category = category

    @property
    def actions(self):
        """
        Gets the actions of this DialerRulesetConfigChangeRule.


        :return: The actions of this DialerRulesetConfigChangeRule.
        :rtype: list[DialerRulesetConfigChangeAction]
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """
        Sets the actions of this DialerRulesetConfigChangeRule.


        :param actions: The actions of this DialerRulesetConfigChangeRule.
        :type: list[DialerRulesetConfigChangeAction]
        """
        
        self._actions = actions

    @property
    def conditions(self):
        """
        Gets the conditions of this DialerRulesetConfigChangeRule.


        :return: The conditions of this DialerRulesetConfigChangeRule.
        :rtype: list[DialerRulesetConfigChangeCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """
        Sets the conditions of this DialerRulesetConfigChangeRule.


        :param conditions: The conditions of this DialerRulesetConfigChangeRule.
        :type: list[DialerRulesetConfigChangeCondition]
        """
        
        self._conditions = conditions

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this DialerRulesetConfigChangeRule.


        :return: The additional_properties of this DialerRulesetConfigChangeRule.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this DialerRulesetConfigChangeRule.


        :param additional_properties: The additional_properties of this DialerRulesetConfigChangeRule.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ArchitectFlowNotificationArchitectOperation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ArchitectFlowNotificationArchitectOperation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'complete': 'bool',
            'user': 'ArchitectFlowNotificationUser',
            'client': 'ArchitectFlowNotificationClient',
            'action_name': 'str',
            'action_status': 'str',
            'error_message': 'str',
            'error_code': 'str',
            'error_message_params': 'ArchitectFlowNotificationErrorMessageParams',
            'error_details': 'list[ArchitectFlowNotificationErrorDetail]'
        }

        self.attribute_map = {
            'id': 'id',
            'complete': 'complete',
            'user': 'user',
            'client': 'client',
            'action_name': 'actionName',
            'action_status': 'actionStatus',
            'error_message': 'errorMessage',
            'error_code': 'errorCode',
            'error_message_params': 'errorMessageParams',
            'error_details': 'errorDetails'
        }

        self._id = None
        self._complete = None
        self._user = None
        self._client = None
        self._action_name = None
        self._action_status = None
        self._error_message = None
        self._error_code = None
        self._error_message_params = None
        self._error_details = None

    @property
    def id(self):
        """
        Gets the id of this ArchitectFlowNotificationArchitectOperation.


        :return: The id of this ArchitectFlowNotificationArchitectOperation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ArchitectFlowNotificationArchitectOperation.


        :param id: The id of this ArchitectFlowNotificationArchitectOperation.
        :type: str
        """
        
        self._id = id

    @property
    def complete(self):
        """
        Gets the complete of this ArchitectFlowNotificationArchitectOperation.


        :return: The complete of this ArchitectFlowNotificationArchitectOperation.
        :rtype: bool
        """
        return self._complete

    @complete.setter
    def complete(self, complete):
        """
        Sets the complete of this ArchitectFlowNotificationArchitectOperation.


        :param complete: The complete of this ArchitectFlowNotificationArchitectOperation.
        :type: bool
        """
        
        self._complete = complete

    @property
    def user(self):
        """
        Gets the user of this ArchitectFlowNotificationArchitectOperation.


        :return: The user of this ArchitectFlowNotificationArchitectOperation.
        :rtype: ArchitectFlowNotificationUser
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this ArchitectFlowNotificationArchitectOperation.


        :param user: The user of this ArchitectFlowNotificationArchitectOperation.
        :type: ArchitectFlowNotificationUser
        """
        
        self._user = user

    @property
    def client(self):
        """
        Gets the client of this ArchitectFlowNotificationArchitectOperation.


        :return: The client of this ArchitectFlowNotificationArchitectOperation.
        :rtype: ArchitectFlowNotificationClient
        """
        return self._client

    @client.setter
    def client(self, client):
        """
        Sets the client of this ArchitectFlowNotificationArchitectOperation.


        :param client: The client of this ArchitectFlowNotificationArchitectOperation.
        :type: ArchitectFlowNotificationClient
        """
        
        self._client = client

    @property
    def action_name(self):
        """
        Gets the action_name of this ArchitectFlowNotificationArchitectOperation.


        :return: The action_name of this ArchitectFlowNotificationArchitectOperation.
        :rtype: str
        """
        return self._action_name

    @action_name.setter
    def action_name(self, action_name):
        """
        Sets the action_name of this ArchitectFlowNotificationArchitectOperation.


        :param action_name: The action_name of this ArchitectFlowNotificationArchitectOperation.
        :type: str
        """
        allowed_values = ["CREATE", "CHECKIN", "DEBUG", "DELETE", "HISTORY", "PUBLISH", "STATE_CHANGE", "UPDATE", "VALIDATE"]
        if action_name.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for action_name -> " + action_name)
            self._action_name = "outdated_sdk_version"
        else:
            self._action_name = action_name

    @property
    def action_status(self):
        """
        Gets the action_status of this ArchitectFlowNotificationArchitectOperation.


        :return: The action_status of this ArchitectFlowNotificationArchitectOperation.
        :rtype: str
        """
        return self._action_status

    @action_status.setter
    def action_status(self, action_status):
        """
        Sets the action_status of this ArchitectFlowNotificationArchitectOperation.


        :param action_status: The action_status of this ArchitectFlowNotificationArchitectOperation.
        :type: str
        """
        allowed_values = ["LOCKED", "UNLOCKED", "STARTED", "PENDING_GENERATION", "PENDING_BACKEND_NOTIFICATION", "SUCCESS", "FAILURE"]
        if action_status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for action_status -> " + action_status)
            self._action_status = "outdated_sdk_version"
        else:
            self._action_status = action_status

    @property
    def error_message(self):
        """
        Gets the error_message of this ArchitectFlowNotificationArchitectOperation.


        :return: The error_message of this ArchitectFlowNotificationArchitectOperation.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """
        Sets the error_message of this ArchitectFlowNotificationArchitectOperation.


        :param error_message: The error_message of this ArchitectFlowNotificationArchitectOperation.
        :type: str
        """
        
        self._error_message = error_message

    @property
    def error_code(self):
        """
        Gets the error_code of this ArchitectFlowNotificationArchitectOperation.


        :return: The error_code of this ArchitectFlowNotificationArchitectOperation.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """
        Sets the error_code of this ArchitectFlowNotificationArchitectOperation.


        :param error_code: The error_code of this ArchitectFlowNotificationArchitectOperation.
        :type: str
        """
        
        self._error_code = error_code

    @property
    def error_message_params(self):
        """
        Gets the error_message_params of this ArchitectFlowNotificationArchitectOperation.


        :return: The error_message_params of this ArchitectFlowNotificationArchitectOperation.
        :rtype: ArchitectFlowNotificationErrorMessageParams
        """
        return self._error_message_params

    @error_message_params.setter
    def error_message_params(self, error_message_params):
        """
        Sets the error_message_params of this ArchitectFlowNotificationArchitectOperation.


        :param error_message_params: The error_message_params of this ArchitectFlowNotificationArchitectOperation.
        :type: ArchitectFlowNotificationErrorMessageParams
        """
        
        self._error_message_params = error_message_params

    @property
    def error_details(self):
        """
        Gets the error_details of this ArchitectFlowNotificationArchitectOperation.


        :return: The error_details of this ArchitectFlowNotificationArchitectOperation.
        :rtype: list[ArchitectFlowNotificationErrorDetail]
        """
        return self._error_details

    @error_details.setter
    def error_details(self, error_details):
        """
        Sets the error_details of this ArchitectFlowNotificationArchitectOperation.


        :param error_details: The error_details of this ArchitectFlowNotificationArchitectOperation.
        :type: list[ArchitectFlowNotificationErrorDetail]
        """
        
        self._error_details = error_details

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SmsPhoneNumberProvision(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SmsPhoneNumberProvision - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'phone_number': 'str',
            'phone_number_type': 'str',
            'country_code': 'str',
            'address_id': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'phone_number': 'phoneNumber',
            'phone_number_type': 'phoneNumberType',
            'country_code': 'countryCode',
            'address_id': 'addressId',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._phone_number = None
        self._phone_number_type = None
        self._country_code = None
        self._address_id = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this SmsPhoneNumberProvision.
        The globally unique identifier for the object.

        :return: The id of this SmsPhoneNumberProvision.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SmsPhoneNumberProvision.
        The globally unique identifier for the object.

        :param id: The id of this SmsPhoneNumberProvision.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this SmsPhoneNumberProvision.


        :return: The name of this SmsPhoneNumberProvision.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SmsPhoneNumberProvision.


        :param name: The name of this SmsPhoneNumberProvision.
        :type: str
        """
        
        self._name = name

    @property
    def phone_number(self):
        """
        Gets the phone_number of this SmsPhoneNumberProvision.
        A phone number to be used for SMS communications. E.g. +13175555555 or +34234234234

        :return: The phone_number of this SmsPhoneNumberProvision.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this SmsPhoneNumberProvision.
        A phone number to be used for SMS communications. E.g. +13175555555 or +34234234234

        :param phone_number: The phone_number of this SmsPhoneNumberProvision.
        :type: str
        """
        
        self._phone_number = phone_number

    @property
    def phone_number_type(self):
        """
        Gets the phone_number_type of this SmsPhoneNumberProvision.
        Type of the phone number provisioned.

        :return: The phone_number_type of this SmsPhoneNumberProvision.
        :rtype: str
        """
        return self._phone_number_type

    @phone_number_type.setter
    def phone_number_type(self, phone_number_type):
        """
        Sets the phone_number_type of this SmsPhoneNumberProvision.
        Type of the phone number provisioned.

        :param phone_number_type: The phone_number_type of this SmsPhoneNumberProvision.
        :type: str
        """
        allowed_values = ["local", "mobile", "tollfree", "shortcode"]
        if phone_number_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for phone_number_type -> " + phone_number_type)
            self._phone_number_type = "outdated_sdk_version"
        else:
            self._phone_number_type = phone_number_type

    @property
    def country_code(self):
        """
        Gets the country_code of this SmsPhoneNumberProvision.
        The ISO 3166-1 alpha-2 country code of the country this phone number is associated with.

        :return: The country_code of this SmsPhoneNumberProvision.
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """
        Sets the country_code of this SmsPhoneNumberProvision.
        The ISO 3166-1 alpha-2 country code of the country this phone number is associated with.

        :param country_code: The country_code of this SmsPhoneNumberProvision.
        :type: str
        """
        
        self._country_code = country_code

    @property
    def address_id(self):
        """
        Gets the address_id of this SmsPhoneNumberProvision.
        The id of an address added on your account. Due to regulatory requirements in some countries, an address may be required when provisioning a sms number. In those cases you should provide the provisioned sms address id here

        :return: The address_id of this SmsPhoneNumberProvision.
        :rtype: str
        """
        return self._address_id

    @address_id.setter
    def address_id(self, address_id):
        """
        Sets the address_id of this SmsPhoneNumberProvision.
        The id of an address added on your account. Due to regulatory requirements in some countries, an address may be required when provisioning a sms number. In those cases you should provide the provisioned sms address id here

        :param address_id: The address_id of this SmsPhoneNumberProvision.
        :type: str
        """
        
        self._address_id = address_id

    @property
    def self_uri(self):
        """
        Gets the self_uri of this SmsPhoneNumberProvision.
        The URI for this object

        :return: The self_uri of this SmsPhoneNumberProvision.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this SmsPhoneNumberProvision.
        The URI for this object

        :param self_uri: The self_uri of this SmsPhoneNumberProvision.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AuditLogMessage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AuditLogMessage - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'user_home_org_id': 'str',
            'user': 'DomainEntityRef',
            'client': 'AddressableEntityRef',
            'remote_ip': 'list[str]',
            'service_name': 'str',
            'event_date': 'datetime',
            'message': 'MessageInfo',
            'action': 'str',
            'entity': 'DomainEntityRef',
            'entity_type': 'str',
            'property_changes': 'list[PropertyChange]',
            'context': 'dict(str, str)'
        }

        self.attribute_map = {
            'id': 'id',
            'user_home_org_id': 'userHomeOrgId',
            'user': 'user',
            'client': 'client',
            'remote_ip': 'remoteIp',
            'service_name': 'serviceName',
            'event_date': 'eventDate',
            'message': 'message',
            'action': 'action',
            'entity': 'entity',
            'entity_type': 'entityType',
            'property_changes': 'propertyChanges',
            'context': 'context'
        }

        self._id = None
        self._user_home_org_id = None
        self._user = None
        self._client = None
        self._remote_ip = None
        self._service_name = None
        self._event_date = None
        self._message = None
        self._action = None
        self._entity = None
        self._entity_type = None
        self._property_changes = None
        self._context = None

    @property
    def id(self):
        """
        Gets the id of this AuditLogMessage.
        Id of the audit message.

        :return: The id of this AuditLogMessage.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AuditLogMessage.
        Id of the audit message.

        :param id: The id of this AuditLogMessage.
        :type: str
        """
        
        self._id = id

    @property
    def user_home_org_id(self):
        """
        Gets the user_home_org_id of this AuditLogMessage.
        Home Organization Id associated with this audit message.

        :return: The user_home_org_id of this AuditLogMessage.
        :rtype: str
        """
        return self._user_home_org_id

    @user_home_org_id.setter
    def user_home_org_id(self, user_home_org_id):
        """
        Sets the user_home_org_id of this AuditLogMessage.
        Home Organization Id associated with this audit message.

        :param user_home_org_id: The user_home_org_id of this AuditLogMessage.
        :type: str
        """
        
        self._user_home_org_id = user_home_org_id

    @property
    def user(self):
        """
        Gets the user of this AuditLogMessage.
        User associated with this audit message.

        :return: The user of this AuditLogMessage.
        :rtype: DomainEntityRef
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this AuditLogMessage.
        User associated with this audit message.

        :param user: The user of this AuditLogMessage.
        :type: DomainEntityRef
        """
        
        self._user = user

    @property
    def client(self):
        """
        Gets the client of this AuditLogMessage.
        Client associated with this audit message.

        :return: The client of this AuditLogMessage.
        :rtype: AddressableEntityRef
        """
        return self._client

    @client.setter
    def client(self, client):
        """
        Sets the client of this AuditLogMessage.
        Client associated with this audit message.

        :param client: The client of this AuditLogMessage.
        :type: AddressableEntityRef
        """
        
        self._client = client

    @property
    def remote_ip(self):
        """
        Gets the remote_ip of this AuditLogMessage.
        List of IP addresses of systems that originated or handled the request.

        :return: The remote_ip of this AuditLogMessage.
        :rtype: list[str]
        """
        return self._remote_ip

    @remote_ip.setter
    def remote_ip(self, remote_ip):
        """
        Sets the remote_ip of this AuditLogMessage.
        List of IP addresses of systems that originated or handled the request.

        :param remote_ip: The remote_ip of this AuditLogMessage.
        :type: list[str]
        """
        
        self._remote_ip = remote_ip

    @property
    def service_name(self):
        """
        Gets the service_name of this AuditLogMessage.
        Name of the service that logged this audit message.

        :return: The service_name of this AuditLogMessage.
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """
        Sets the service_name of this AuditLogMessage.
        Name of the service that logged this audit message.

        :param service_name: The service_name of this AuditLogMessage.
        :type: str
        """
        allowed_values = ["Architect", "ContactCenter", "ContentManagement", "PeoplePermissions", "Presence", "Quality", "LanguageUnderstanding", "TopicsDefinitions", "PredictiveEngagement", "WorkforceManagement", "Triggers", "ResponseManagement", "Groups", "Telephony", "Outbound", "SpeechAndTextAnalytics", "Routing"]
        if service_name.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for service_name -> " + service_name)
            self._service_name = "outdated_sdk_version"
        else:
            self._service_name = service_name

    @property
    def event_date(self):
        """
        Gets the event_date of this AuditLogMessage.
        Date and time of when the audit message was logged. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The event_date of this AuditLogMessage.
        :rtype: datetime
        """
        return self._event_date

    @event_date.setter
    def event_date(self, event_date):
        """
        Sets the event_date of this AuditLogMessage.
        Date and time of when the audit message was logged. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param event_date: The event_date of this AuditLogMessage.
        :type: datetime
        """
        
        self._event_date = event_date

    @property
    def message(self):
        """
        Gets the message of this AuditLogMessage.
        Message describing the event being audited.

        :return: The message of this AuditLogMessage.
        :rtype: MessageInfo
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this AuditLogMessage.
        Message describing the event being audited.

        :param message: The message of this AuditLogMessage.
        :type: MessageInfo
        """
        
        self._message = message

    @property
    def action(self):
        """
        Gets the action of this AuditLogMessage.
        Action that took place.

        :return: The action of this AuditLogMessage.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this AuditLogMessage.
        Action that took place.

        :param action: The action of this AuditLogMessage.
        :type: str
        """
        allowed_values = ["Create", "View", "Update", "Delete", "Download", "Upload", "MemberAdd", "MemberUpdate", "MemberRemove", "Read", "ApplyProtection", "RevokeProtection", "UpdateRetention", "ReadAll", "Execute", "Publish", "Unpublish", "Activate", "Checkin", "Checkout", "Deactivate", "Debug", "Save", "Revert", "Transcode", "Enable", "Disable", "Authorize", "Deauthorize", "Authenticate", "ChangePassword", "Revoke", "Export", "Append", "Recycle"]
        if action.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for action -> " + action)
            self._action = "outdated_sdk_version"
        else:
            self._action = action

    @property
    def entity(self):
        """
        Gets the entity of this AuditLogMessage.
        Entity that was impacted.

        :return: The entity of this AuditLogMessage.
        :rtype: DomainEntityRef
        """
        return self._entity

    @entity.setter
    def entity(self, entity):
        """
        Sets the entity of this AuditLogMessage.
        Entity that was impacted.

        :param entity: The entity of this AuditLogMessage.
        :type: DomainEntityRef
        """
        
        self._entity = entity

    @property
    def entity_type(self):
        """
        Gets the entity_type of this AuditLogMessage.
        Type of the entity that was impacted.

        :return: The entity_type of this AuditLogMessage.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this AuditLogMessage.
        Type of the entity that was impacted.

        :param entity_type: The entity_type of this AuditLogMessage.
        :type: str
        """
        allowed_values = ["Document", "Queue", "Recording", "Role", "VoicemailPolicy", "VoicemailUserPolicy", "UserPresence", "WrapupCode", "MaxOrgRoutingUtilizationCapacity", "AccessToken", "OAuthClient", "OAuthClientAuthorization", "AuthOrganization", "AuthUser", "OrganizationAuthorizationTrust", "OrganizationAuthorizationUserTrust", "BulkActions", "Feedback", "Topic", "Program", "Segment", "Outcome", "SessionType", "EventType", "ClickstreamSettings", "Schedule", "ScheduleGroup", "EmergencyGroup", "IVR", "Trigger", "Response", "DependencyTrackingBuild", "Flow", "Prompt", "PromptResource", "FlowOutcome", "FlowMilestone", "Team", "Edge", "EdgeGroup", "Trunk", "TrunkBase", "DID", "DIDPool", "Extension", "ExtensionPool", "Phone", "PhoneBase", "Line", "LineBase", "OutboundRoute", "NumberPlan", "Site", "AttemptLimits", "CallableTimeSet", "Campaign", "CampaignRule", "Sequence", "ContactList", "ContactListFilter", "DNCList", "CallAnalysisResponseSet", "RuleSet", "CampaignSchedule", "SequenceSchedule", "OrganizationSettings", "WrapUpCodeMapping", "MessagingCampaign", "TranscriptionSettings", "RoutingTranscriptionSettings", "SpeechTextAnalyticsSettings", "Predictor"]
        if entity_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for entity_type -> " + entity_type)
            self._entity_type = "outdated_sdk_version"
        else:
            self._entity_type = entity_type

    @property
    def property_changes(self):
        """
        Gets the property_changes of this AuditLogMessage.
        List of properties that were changed and changes made to those properties.

        :return: The property_changes of this AuditLogMessage.
        :rtype: list[PropertyChange]
        """
        return self._property_changes

    @property_changes.setter
    def property_changes(self, property_changes):
        """
        Sets the property_changes of this AuditLogMessage.
        List of properties that were changed and changes made to those properties.

        :param property_changes: The property_changes of this AuditLogMessage.
        :type: list[PropertyChange]
        """
        
        self._property_changes = property_changes

    @property
    def context(self):
        """
        Gets the context of this AuditLogMessage.
        Additional context for this message.

        :return: The context of this AuditLogMessage.
        :rtype: dict(str, str)
        """
        return self._context

    @context.setter
    def context(self, context):
        """
        Sets the context of this AuditLogMessage.
        Additional context for this message.

        :param context: The context of this AuditLogMessage.
        :type: dict(str, str)
        """
        
        self._context = context

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Dependency(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Dependency - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'version': 'str',
            'type': 'str',
            'deleted': 'bool',
            'updated': 'bool',
            'state_unknown': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'version': 'version',
            'type': 'type',
            'deleted': 'deleted',
            'updated': 'updated',
            'state_unknown': 'stateUnknown',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._version = None
        self._type = None
        self._deleted = None
        self._updated = None
        self._state_unknown = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Dependency.
        The dependency identifier

        :return: The id of this Dependency.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Dependency.
        The dependency identifier

        :param id: The id of this Dependency.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Dependency.


        :return: The name of this Dependency.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Dependency.


        :param name: The name of this Dependency.
        :type: str
        """
        
        self._name = name

    @property
    def version(self):
        """
        Gets the version of this Dependency.


        :return: The version of this Dependency.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Dependency.


        :param version: The version of this Dependency.
        :type: str
        """
        
        self._version = version

    @property
    def type(self):
        """
        Gets the type of this Dependency.


        :return: The type of this Dependency.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Dependency.


        :param type: The type of this Dependency.
        :type: str
        """
        allowed_values = ["ACDLANGUAGE", "ACDSKILL", "ACDWRAPUPCODE", "BOTCONNECTORBOT", "BOTCONNECTORINTEGRATION", "BOTFLOW", "BRIDGEACTION", "COMMONMODULEFLOW", "COMPOSERSCRIPT", "CONTACTLIST", "DATAACTION", "DATATABLE", "DIALOGENGINEBOT", "DIALOGENGINEBOTVERSION", "DIALOGFLOWAGENT", "EMAILROUTE", "EMERGENCYGROUP", "FLOWACTION", "FLOWDATATYPE", "FLOWMILESTONE", "FLOWOUTCOME", "GROUP", "INBOUNDCALLFLOW", "INBOUNDCHATFLOW", "INBOUNDEMAILFLOW", "INBOUNDSHORTMESSAGEFLOW", "INQUEUECALLFLOW", "IVRCONFIGURATION", "LANGUAGE", "LEXBOT", "LEXBOTALIAS", "NLUDOMAIN", "OUTBOUNDCALLFLOW", "QUEUE", "RECORDINGPOLICY", "RESPONSE", "SCHEDULE", "SCHEDULEGROUP", "SECUREACTION", "SECURECALLFLOW", "SURVEYINVITEFLOW", "SYSTEMPROMPT", "TTSENGINE", "TTSVOICE", "USER", "USERPROMPT", "WIDGET", "WORKFLOW"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def deleted(self):
        """
        Gets the deleted of this Dependency.


        :return: The deleted of this Dependency.
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """
        Sets the deleted of this Dependency.


        :param deleted: The deleted of this Dependency.
        :type: bool
        """
        
        self._deleted = deleted

    @property
    def updated(self):
        """
        Gets the updated of this Dependency.


        :return: The updated of this Dependency.
        :rtype: bool
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """
        Sets the updated of this Dependency.


        :param updated: The updated of this Dependency.
        :type: bool
        """
        
        self._updated = updated

    @property
    def state_unknown(self):
        """
        Gets the state_unknown of this Dependency.


        :return: The state_unknown of this Dependency.
        :rtype: bool
        """
        return self._state_unknown

    @state_unknown.setter
    def state_unknown(self, state_unknown):
        """
        Sets the state_unknown of this Dependency.


        :param state_unknown: The state_unknown of this Dependency.
        :type: bool
        """
        
        self._state_unknown = state_unknown

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Dependency.
        The URI for this object

        :return: The self_uri of this Dependency.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Dependency.
        The URI for this object

        :param self_uri: The self_uri of this Dependency.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmUserNotificationTopicTimeOffRequestNotification(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmUserNotificationTopicTimeOffRequestNotification - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'time_off_request_id': 'str',
            'user': 'WfmUserNotificationTopicUserReference',
            'is_full_day_request': 'bool',
            'status': 'str',
            'partial_day_start_date_times': 'list[datetime]',
            'full_day_management_unit_dates': 'list[str]'
        }

        self.attribute_map = {
            'time_off_request_id': 'timeOffRequestId',
            'user': 'user',
            'is_full_day_request': 'isFullDayRequest',
            'status': 'status',
            'partial_day_start_date_times': 'partialDayStartDateTimes',
            'full_day_management_unit_dates': 'fullDayManagementUnitDates'
        }

        self._time_off_request_id = None
        self._user = None
        self._is_full_day_request = None
        self._status = None
        self._partial_day_start_date_times = None
        self._full_day_management_unit_dates = None

    @property
    def time_off_request_id(self):
        """
        Gets the time_off_request_id of this WfmUserNotificationTopicTimeOffRequestNotification.


        :return: The time_off_request_id of this WfmUserNotificationTopicTimeOffRequestNotification.
        :rtype: str
        """
        return self._time_off_request_id

    @time_off_request_id.setter
    def time_off_request_id(self, time_off_request_id):
        """
        Sets the time_off_request_id of this WfmUserNotificationTopicTimeOffRequestNotification.


        :param time_off_request_id: The time_off_request_id of this WfmUserNotificationTopicTimeOffRequestNotification.
        :type: str
        """
        
        self._time_off_request_id = time_off_request_id

    @property
    def user(self):
        """
        Gets the user of this WfmUserNotificationTopicTimeOffRequestNotification.


        :return: The user of this WfmUserNotificationTopicTimeOffRequestNotification.
        :rtype: WfmUserNotificationTopicUserReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this WfmUserNotificationTopicTimeOffRequestNotification.


        :param user: The user of this WfmUserNotificationTopicTimeOffRequestNotification.
        :type: WfmUserNotificationTopicUserReference
        """
        
        self._user = user

    @property
    def is_full_day_request(self):
        """
        Gets the is_full_day_request of this WfmUserNotificationTopicTimeOffRequestNotification.


        :return: The is_full_day_request of this WfmUserNotificationTopicTimeOffRequestNotification.
        :rtype: bool
        """
        return self._is_full_day_request

    @is_full_day_request.setter
    def is_full_day_request(self, is_full_day_request):
        """
        Sets the is_full_day_request of this WfmUserNotificationTopicTimeOffRequestNotification.


        :param is_full_day_request: The is_full_day_request of this WfmUserNotificationTopicTimeOffRequestNotification.
        :type: bool
        """
        
        self._is_full_day_request = is_full_day_request

    @property
    def status(self):
        """
        Gets the status of this WfmUserNotificationTopicTimeOffRequestNotification.


        :return: The status of this WfmUserNotificationTopicTimeOffRequestNotification.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this WfmUserNotificationTopicTimeOffRequestNotification.


        :param status: The status of this WfmUserNotificationTopicTimeOffRequestNotification.
        :type: str
        """
        allowed_values = ["PENDING", "APPROVED", "DENIED", "CANCELED"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def partial_day_start_date_times(self):
        """
        Gets the partial_day_start_date_times of this WfmUserNotificationTopicTimeOffRequestNotification.


        :return: The partial_day_start_date_times of this WfmUserNotificationTopicTimeOffRequestNotification.
        :rtype: list[datetime]
        """
        return self._partial_day_start_date_times

    @partial_day_start_date_times.setter
    def partial_day_start_date_times(self, partial_day_start_date_times):
        """
        Sets the partial_day_start_date_times of this WfmUserNotificationTopicTimeOffRequestNotification.


        :param partial_day_start_date_times: The partial_day_start_date_times of this WfmUserNotificationTopicTimeOffRequestNotification.
        :type: list[datetime]
        """
        
        self._partial_day_start_date_times = partial_day_start_date_times

    @property
    def full_day_management_unit_dates(self):
        """
        Gets the full_day_management_unit_dates of this WfmUserNotificationTopicTimeOffRequestNotification.


        :return: The full_day_management_unit_dates of this WfmUserNotificationTopicTimeOffRequestNotification.
        :rtype: list[str]
        """
        return self._full_day_management_unit_dates

    @full_day_management_unit_dates.setter
    def full_day_management_unit_dates(self, full_day_management_unit_dates):
        """
        Sets the full_day_management_unit_dates of this WfmUserNotificationTopicTimeOffRequestNotification.


        :param full_day_management_unit_dates: The full_day_management_unit_dates of this WfmUserNotificationTopicTimeOffRequestNotification.
        :type: list[str]
        """
        
        self._full_day_management_unit_dates = full_day_management_unit_dates

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SendAgentlessOutboundMessageRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SendAgentlessOutboundMessageRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'from_address': 'str',
            'to_address': 'str',
            'to_address_messenger_type': 'str',
            'text_body': 'str'
        }

        self.attribute_map = {
            'from_address': 'fromAddress',
            'to_address': 'toAddress',
            'to_address_messenger_type': 'toAddressMessengerType',
            'text_body': 'textBody'
        }

        self._from_address = None
        self._to_address = None
        self._to_address_messenger_type = None
        self._text_body = None

    @property
    def from_address(self):
        """
        Gets the from_address of this SendAgentlessOutboundMessageRequest.
        The messaging address of the sender of the message. For an SMS messenger type, this must be a currently provisioned sms phone number.

        :return: The from_address of this SendAgentlessOutboundMessageRequest.
        :rtype: str
        """
        return self._from_address

    @from_address.setter
    def from_address(self, from_address):
        """
        Sets the from_address of this SendAgentlessOutboundMessageRequest.
        The messaging address of the sender of the message. For an SMS messenger type, this must be a currently provisioned sms phone number.

        :param from_address: The from_address of this SendAgentlessOutboundMessageRequest.
        :type: str
        """
        
        self._from_address = from_address

    @property
    def to_address(self):
        """
        Gets the to_address of this SendAgentlessOutboundMessageRequest.
        The messaging address of the recipient of the message. For an SMS messenger type, the phone number address must be in E.164 format. E.g. +13175555555 or +34234234234.

        :return: The to_address of this SendAgentlessOutboundMessageRequest.
        :rtype: str
        """
        return self._to_address

    @to_address.setter
    def to_address(self, to_address):
        """
        Sets the to_address of this SendAgentlessOutboundMessageRequest.
        The messaging address of the recipient of the message. For an SMS messenger type, the phone number address must be in E.164 format. E.g. +13175555555 or +34234234234.

        :param to_address: The to_address of this SendAgentlessOutboundMessageRequest.
        :type: str
        """
        
        self._to_address = to_address

    @property
    def to_address_messenger_type(self):
        """
        Gets the to_address_messenger_type of this SendAgentlessOutboundMessageRequest.
        The recipient messaging address messenger type. Currently SMS is the only supported type.

        :return: The to_address_messenger_type of this SendAgentlessOutboundMessageRequest.
        :rtype: str
        """
        return self._to_address_messenger_type

    @to_address_messenger_type.setter
    def to_address_messenger_type(self, to_address_messenger_type):
        """
        Sets the to_address_messenger_type of this SendAgentlessOutboundMessageRequest.
        The recipient messaging address messenger type. Currently SMS is the only supported type.

        :param to_address_messenger_type: The to_address_messenger_type of this SendAgentlessOutboundMessageRequest.
        :type: str
        """
        allowed_values = ["sms", "facebook", "twitter", "line", "whatsapp", "webmessaging", "open"]
        if to_address_messenger_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for to_address_messenger_type -> " + to_address_messenger_type)
            self._to_address_messenger_type = "outdated_sdk_version"
        else:
            self._to_address_messenger_type = to_address_messenger_type

    @property
    def text_body(self):
        """
        Gets the text_body of this SendAgentlessOutboundMessageRequest.
        The text of the message to send

        :return: The text_body of this SendAgentlessOutboundMessageRequest.
        :rtype: str
        """
        return self._text_body

    @text_body.setter
    def text_body(self, text_body):
        """
        Sets the text_body of this SendAgentlessOutboundMessageRequest.
        The text of the message to send

        :param text_body: The text_body of this SendAgentlessOutboundMessageRequest.
        :type: str
        """
        
        self._text_body = text_body

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'user': 'WfmTimeOffRequestUpdateTopicUserReference',
            'is_full_day_request': 'bool',
            'marked_as_read': 'bool',
            'activity_code_id': 'str',
            'status': 'str',
            'partial_day_start_date_times': 'list[str]',
            'full_day_management_unit_dates': 'list[str]',
            'daily_duration_minutes': 'int',
            'notes': 'str',
            'reviewed_date': 'str',
            'reviewed_by': 'str',
            'submitted_date': 'str',
            'submitted_by': 'str',
            'modified_date': 'str',
            'modified_by': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'user': 'user',
            'is_full_day_request': 'isFullDayRequest',
            'marked_as_read': 'markedAsRead',
            'activity_code_id': 'activityCodeId',
            'status': 'status',
            'partial_day_start_date_times': 'partialDayStartDateTimes',
            'full_day_management_unit_dates': 'fullDayManagementUnitDates',
            'daily_duration_minutes': 'dailyDurationMinutes',
            'notes': 'notes',
            'reviewed_date': 'reviewedDate',
            'reviewed_by': 'reviewedBy',
            'submitted_date': 'submittedDate',
            'submitted_by': 'submittedBy',
            'modified_date': 'modifiedDate',
            'modified_by': 'modifiedBy'
        }

        self._id = None
        self._user = None
        self._is_full_day_request = None
        self._marked_as_read = None
        self._activity_code_id = None
        self._status = None
        self._partial_day_start_date_times = None
        self._full_day_management_unit_dates = None
        self._daily_duration_minutes = None
        self._notes = None
        self._reviewed_date = None
        self._reviewed_by = None
        self._submitted_date = None
        self._submitted_by = None
        self._modified_date = None
        self._modified_by = None

    @property
    def id(self):
        """
        Gets the id of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :return: The id of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :param id: The id of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :type: str
        """
        
        self._id = id

    @property
    def user(self):
        """
        Gets the user of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :return: The user of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :rtype: WfmTimeOffRequestUpdateTopicUserReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :param user: The user of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :type: WfmTimeOffRequestUpdateTopicUserReference
        """
        
        self._user = user

    @property
    def is_full_day_request(self):
        """
        Gets the is_full_day_request of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :return: The is_full_day_request of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :rtype: bool
        """
        return self._is_full_day_request

    @is_full_day_request.setter
    def is_full_day_request(self, is_full_day_request):
        """
        Sets the is_full_day_request of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :param is_full_day_request: The is_full_day_request of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :type: bool
        """
        
        self._is_full_day_request = is_full_day_request

    @property
    def marked_as_read(self):
        """
        Gets the marked_as_read of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :return: The marked_as_read of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :rtype: bool
        """
        return self._marked_as_read

    @marked_as_read.setter
    def marked_as_read(self, marked_as_read):
        """
        Sets the marked_as_read of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :param marked_as_read: The marked_as_read of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :type: bool
        """
        
        self._marked_as_read = marked_as_read

    @property
    def activity_code_id(self):
        """
        Gets the activity_code_id of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :return: The activity_code_id of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :rtype: str
        """
        return self._activity_code_id

    @activity_code_id.setter
    def activity_code_id(self, activity_code_id):
        """
        Sets the activity_code_id of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :param activity_code_id: The activity_code_id of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :type: str
        """
        
        self._activity_code_id = activity_code_id

    @property
    def status(self):
        """
        Gets the status of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :return: The status of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :param status: The status of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :type: str
        """
        allowed_values = ["PENDING", "APPROVED", "DENIED", "CANCELED"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def partial_day_start_date_times(self):
        """
        Gets the partial_day_start_date_times of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :return: The partial_day_start_date_times of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :rtype: list[str]
        """
        return self._partial_day_start_date_times

    @partial_day_start_date_times.setter
    def partial_day_start_date_times(self, partial_day_start_date_times):
        """
        Sets the partial_day_start_date_times of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :param partial_day_start_date_times: The partial_day_start_date_times of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :type: list[str]
        """
        
        self._partial_day_start_date_times = partial_day_start_date_times

    @property
    def full_day_management_unit_dates(self):
        """
        Gets the full_day_management_unit_dates of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :return: The full_day_management_unit_dates of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :rtype: list[str]
        """
        return self._full_day_management_unit_dates

    @full_day_management_unit_dates.setter
    def full_day_management_unit_dates(self, full_day_management_unit_dates):
        """
        Sets the full_day_management_unit_dates of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :param full_day_management_unit_dates: The full_day_management_unit_dates of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :type: list[str]
        """
        
        self._full_day_management_unit_dates = full_day_management_unit_dates

    @property
    def daily_duration_minutes(self):
        """
        Gets the daily_duration_minutes of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :return: The daily_duration_minutes of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :rtype: int
        """
        return self._daily_duration_minutes

    @daily_duration_minutes.setter
    def daily_duration_minutes(self, daily_duration_minutes):
        """
        Sets the daily_duration_minutes of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :param daily_duration_minutes: The daily_duration_minutes of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :type: int
        """
        
        self._daily_duration_minutes = daily_duration_minutes

    @property
    def notes(self):
        """
        Gets the notes of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :return: The notes of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """
        Sets the notes of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :param notes: The notes of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :type: str
        """
        
        self._notes = notes

    @property
    def reviewed_date(self):
        """
        Gets the reviewed_date of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :return: The reviewed_date of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :rtype: str
        """
        return self._reviewed_date

    @reviewed_date.setter
    def reviewed_date(self, reviewed_date):
        """
        Sets the reviewed_date of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :param reviewed_date: The reviewed_date of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :type: str
        """
        
        self._reviewed_date = reviewed_date

    @property
    def reviewed_by(self):
        """
        Gets the reviewed_by of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :return: The reviewed_by of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :rtype: str
        """
        return self._reviewed_by

    @reviewed_by.setter
    def reviewed_by(self, reviewed_by):
        """
        Sets the reviewed_by of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :param reviewed_by: The reviewed_by of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :type: str
        """
        
        self._reviewed_by = reviewed_by

    @property
    def submitted_date(self):
        """
        Gets the submitted_date of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :return: The submitted_date of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :rtype: str
        """
        return self._submitted_date

    @submitted_date.setter
    def submitted_date(self, submitted_date):
        """
        Sets the submitted_date of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :param submitted_date: The submitted_date of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :type: str
        """
        
        self._submitted_date = submitted_date

    @property
    def submitted_by(self):
        """
        Gets the submitted_by of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :return: The submitted_by of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :rtype: str
        """
        return self._submitted_by

    @submitted_by.setter
    def submitted_by(self, submitted_by):
        """
        Sets the submitted_by of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :param submitted_by: The submitted_by of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :type: str
        """
        
        self._submitted_by = submitted_by

    @property
    def modified_date(self):
        """
        Gets the modified_date of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :return: The modified_date of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :rtype: str
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :param modified_date: The modified_date of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :type: str
        """
        
        self._modified_date = modified_date

    @property
    def modified_by(self):
        """
        Gets the modified_by of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :return: The modified_by of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.


        :param modified_by: The modified_by of this WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate.
        :type: str
        """
        
        self._modified_by = modified_by

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class OverallBestPointsItem(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        OverallBestPointsItem - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'granularity_type': 'str',
            'users': 'list[UserReference]',
            'count': 'int',
            'points': 'int',
            'date_start_workday': 'date',
            'date_end_workday': 'date'
        }

        self.attribute_map = {
            'granularity_type': 'granularityType',
            'users': 'users',
            'count': 'count',
            'points': 'points',
            'date_start_workday': 'dateStartWorkday',
            'date_end_workday': 'dateEndWorkday'
        }

        self._granularity_type = None
        self._users = None
        self._count = None
        self._points = None
        self._date_start_workday = None
        self._date_end_workday = None

    @property
    def granularity_type(self):
        """
        Gets the granularity_type of this OverallBestPointsItem.
        Best points aggregation interval granularity

        :return: The granularity_type of this OverallBestPointsItem.
        :rtype: str
        """
        return self._granularity_type

    @granularity_type.setter
    def granularity_type(self, granularity_type):
        """
        Sets the granularity_type of this OverallBestPointsItem.
        Best points aggregation interval granularity

        :param granularity_type: The granularity_type of this OverallBestPointsItem.
        :type: str
        """
        allowed_values = ["Monthly", "Weekly", "Daily"]
        if granularity_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for granularity_type -> " + granularity_type)
            self._granularity_type = "outdated_sdk_version"
        else:
            self._granularity_type = granularity_type

    @property
    def users(self):
        """
        Gets the users of this OverallBestPointsItem.
        List of associated users with the equal points.

        :return: The users of this OverallBestPointsItem.
        :rtype: list[UserReference]
        """
        return self._users

    @users.setter
    def users(self, users):
        """
        Sets the users of this OverallBestPointsItem.
        List of associated users with the equal points.

        :param users: The users of this OverallBestPointsItem.
        :type: list[UserReference]
        """
        
        self._users = users

    @property
    def count(self):
        """
        Gets the count of this OverallBestPointsItem.
        The count of the user IDs in the list

        :return: The count of this OverallBestPointsItem.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this OverallBestPointsItem.
        The count of the user IDs in the list

        :param count: The count of this OverallBestPointsItem.
        :type: int
        """
        
        self._count = count

    @property
    def points(self):
        """
        Gets the points of this OverallBestPointsItem.
        Gamification points

        :return: The points of this OverallBestPointsItem.
        :rtype: int
        """
        return self._points

    @points.setter
    def points(self, points):
        """
        Sets the points of this OverallBestPointsItem.
        Gamification points

        :param points: The points of this OverallBestPointsItem.
        :type: int
        """
        
        self._points = points

    @property
    def date_start_workday(self):
        """
        Gets the date_start_workday of this OverallBestPointsItem.
        Start workday of the best points aggregation interval. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :return: The date_start_workday of this OverallBestPointsItem.
        :rtype: date
        """
        return self._date_start_workday

    @date_start_workday.setter
    def date_start_workday(self, date_start_workday):
        """
        Sets the date_start_workday of this OverallBestPointsItem.
        Start workday of the best points aggregation interval. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :param date_start_workday: The date_start_workday of this OverallBestPointsItem.
        :type: date
        """
        
        self._date_start_workday = date_start_workday

    @property
    def date_end_workday(self):
        """
        Gets the date_end_workday of this OverallBestPointsItem.
        End workday of the best points aggregation interval. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :return: The date_end_workday of this OverallBestPointsItem.
        :rtype: date
        """
        return self._date_end_workday

    @date_end_workday.setter
    def date_end_workday(self, date_end_workday):
        """
        Sets the date_end_workday of this OverallBestPointsItem.
        End workday of the best points aggregation interval. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :param date_end_workday: The date_end_workday of this OverallBestPointsItem.
        :type: date
        """
        
        self._date_end_workday = date_end_workday

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class UpdateUser(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UpdateUser - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'chat': 'Chat',
            'department': 'str',
            'email': 'str',
            'primary_contact_info': 'list[Contact]',
            'addresses': 'list[Contact]',
            'title': 'str',
            'username': 'str',
            'manager': 'str',
            'images': 'list[UserImage]',
            'version': 'int',
            'profile_skills': 'list[str]',
            'locations': 'list[Location]',
            'groups': 'list[Group]',
            'state': 'str',
            'acd_auto_answer': 'bool',
            'certifications': 'list[str]',
            'biography': 'Biography',
            'employer_info': 'EmployerInfo',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'chat': 'chat',
            'department': 'department',
            'email': 'email',
            'primary_contact_info': 'primaryContactInfo',
            'addresses': 'addresses',
            'title': 'title',
            'username': 'username',
            'manager': 'manager',
            'images': 'images',
            'version': 'version',
            'profile_skills': 'profileSkills',
            'locations': 'locations',
            'groups': 'groups',
            'state': 'state',
            'acd_auto_answer': 'acdAutoAnswer',
            'certifications': 'certifications',
            'biography': 'biography',
            'employer_info': 'employerInfo',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._chat = None
        self._department = None
        self._email = None
        self._primary_contact_info = None
        self._addresses = None
        self._title = None
        self._username = None
        self._manager = None
        self._images = None
        self._version = None
        self._profile_skills = None
        self._locations = None
        self._groups = None
        self._state = None
        self._acd_auto_answer = None
        self._certifications = None
        self._biography = None
        self._employer_info = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this UpdateUser.
        The globally unique identifier for the object.

        :return: The id of this UpdateUser.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this UpdateUser.
        The globally unique identifier for the object.

        :param id: The id of this UpdateUser.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this UpdateUser.


        :return: The name of this UpdateUser.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UpdateUser.


        :param name: The name of this UpdateUser.
        :type: str
        """
        
        self._name = name

    @property
    def chat(self):
        """
        Gets the chat of this UpdateUser.


        :return: The chat of this UpdateUser.
        :rtype: Chat
        """
        return self._chat

    @chat.setter
    def chat(self, chat):
        """
        Sets the chat of this UpdateUser.


        :param chat: The chat of this UpdateUser.
        :type: Chat
        """
        
        self._chat = chat

    @property
    def department(self):
        """
        Gets the department of this UpdateUser.


        :return: The department of this UpdateUser.
        :rtype: str
        """
        return self._department

    @department.setter
    def department(self, department):
        """
        Sets the department of this UpdateUser.


        :param department: The department of this UpdateUser.
        :type: str
        """
        
        self._department = department

    @property
    def email(self):
        """
        Gets the email of this UpdateUser.


        :return: The email of this UpdateUser.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this UpdateUser.


        :param email: The email of this UpdateUser.
        :type: str
        """
        
        self._email = email

    @property
    def primary_contact_info(self):
        """
        Gets the primary_contact_info of this UpdateUser.
        The address(s) used for primary contact. Updates to the corresponding address in the addresses list will be reflected here.

        :return: The primary_contact_info of this UpdateUser.
        :rtype: list[Contact]
        """
        return self._primary_contact_info

    @primary_contact_info.setter
    def primary_contact_info(self, primary_contact_info):
        """
        Sets the primary_contact_info of this UpdateUser.
        The address(s) used for primary contact. Updates to the corresponding address in the addresses list will be reflected here.

        :param primary_contact_info: The primary_contact_info of this UpdateUser.
        :type: list[Contact]
        """
        
        self._primary_contact_info = primary_contact_info

    @property
    def addresses(self):
        """
        Gets the addresses of this UpdateUser.
        Email address, phone number, and/or extension for this user. One entry is allowed per media type

        :return: The addresses of this UpdateUser.
        :rtype: list[Contact]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """
        Sets the addresses of this UpdateUser.
        Email address, phone number, and/or extension for this user. One entry is allowed per media type

        :param addresses: The addresses of this UpdateUser.
        :type: list[Contact]
        """
        
        self._addresses = addresses

    @property
    def title(self):
        """
        Gets the title of this UpdateUser.


        :return: The title of this UpdateUser.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this UpdateUser.


        :param title: The title of this UpdateUser.
        :type: str
        """
        
        self._title = title

    @property
    def username(self):
        """
        Gets the username of this UpdateUser.


        :return: The username of this UpdateUser.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """
        Sets the username of this UpdateUser.


        :param username: The username of this UpdateUser.
        :type: str
        """
        
        self._username = username

    @property
    def manager(self):
        """
        Gets the manager of this UpdateUser.


        :return: The manager of this UpdateUser.
        :rtype: str
        """
        return self._manager

    @manager.setter
    def manager(self, manager):
        """
        Sets the manager of this UpdateUser.


        :param manager: The manager of this UpdateUser.
        :type: str
        """
        
        self._manager = manager

    @property
    def images(self):
        """
        Gets the images of this UpdateUser.


        :return: The images of this UpdateUser.
        :rtype: list[UserImage]
        """
        return self._images

    @images.setter
    def images(self, images):
        """
        Sets the images of this UpdateUser.


        :param images: The images of this UpdateUser.
        :type: list[UserImage]
        """
        
        self._images = images

    @property
    def version(self):
        """
        Gets the version of this UpdateUser.
        This value should be the current version of the user. The current version can be obtained with a GET on the user before doing a PATCH.

        :return: The version of this UpdateUser.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this UpdateUser.
        This value should be the current version of the user. The current version can be obtained with a GET on the user before doing a PATCH.

        :param version: The version of this UpdateUser.
        :type: int
        """
        
        self._version = version

    @property
    def profile_skills(self):
        """
        Gets the profile_skills of this UpdateUser.
        Profile skills possessed by the user

        :return: The profile_skills of this UpdateUser.
        :rtype: list[str]
        """
        return self._profile_skills

    @profile_skills.setter
    def profile_skills(self, profile_skills):
        """
        Sets the profile_skills of this UpdateUser.
        Profile skills possessed by the user

        :param profile_skills: The profile_skills of this UpdateUser.
        :type: list[str]
        """
        
        self._profile_skills = profile_skills

    @property
    def locations(self):
        """
        Gets the locations of this UpdateUser.
        The user placement at each site location.

        :return: The locations of this UpdateUser.
        :rtype: list[Location]
        """
        return self._locations

    @locations.setter
    def locations(self, locations):
        """
        Sets the locations of this UpdateUser.
        The user placement at each site location.

        :param locations: The locations of this UpdateUser.
        :type: list[Location]
        """
        
        self._locations = locations

    @property
    def groups(self):
        """
        Gets the groups of this UpdateUser.
        The groups the user is a member of

        :return: The groups of this UpdateUser.
        :rtype: list[Group]
        """
        return self._groups

    @groups.setter
    def groups(self, groups):
        """
        Sets the groups of this UpdateUser.
        The groups the user is a member of

        :param groups: The groups of this UpdateUser.
        :type: list[Group]
        """
        
        self._groups = groups

    @property
    def state(self):
        """
        Gets the state of this UpdateUser.
        The state of the user. This property can be used to restore a deleted user or transition between active and inactive. If specified, it is the only modifiable field.

        :return: The state of this UpdateUser.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this UpdateUser.
        The state of the user. This property can be used to restore a deleted user or transition between active and inactive. If specified, it is the only modifiable field.

        :param state: The state of this UpdateUser.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def acd_auto_answer(self):
        """
        Gets the acd_auto_answer of this UpdateUser.
        The value that denotes if acdAutoAnswer is set on the user

        :return: The acd_auto_answer of this UpdateUser.
        :rtype: bool
        """
        return self._acd_auto_answer

    @acd_auto_answer.setter
    def acd_auto_answer(self, acd_auto_answer):
        """
        Sets the acd_auto_answer of this UpdateUser.
        The value that denotes if acdAutoAnswer is set on the user

        :param acd_auto_answer: The acd_auto_answer of this UpdateUser.
        :type: bool
        """
        
        self._acd_auto_answer = acd_auto_answer

    @property
    def certifications(self):
        """
        Gets the certifications of this UpdateUser.


        :return: The certifications of this UpdateUser.
        :rtype: list[str]
        """
        return self._certifications

    @certifications.setter
    def certifications(self, certifications):
        """
        Sets the certifications of this UpdateUser.


        :param certifications: The certifications of this UpdateUser.
        :type: list[str]
        """
        
        self._certifications = certifications

    @property
    def biography(self):
        """
        Gets the biography of this UpdateUser.


        :return: The biography of this UpdateUser.
        :rtype: Biography
        """
        return self._biography

    @biography.setter
    def biography(self, biography):
        """
        Sets the biography of this UpdateUser.


        :param biography: The biography of this UpdateUser.
        :type: Biography
        """
        
        self._biography = biography

    @property
    def employer_info(self):
        """
        Gets the employer_info of this UpdateUser.


        :return: The employer_info of this UpdateUser.
        :rtype: EmployerInfo
        """
        return self._employer_info

    @employer_info.setter
    def employer_info(self, employer_info):
        """
        Sets the employer_info of this UpdateUser.


        :param employer_info: The employer_info of this UpdateUser.
        :type: EmployerInfo
        """
        
        self._employer_info = employer_info

    @property
    def self_uri(self):
        """
        Gets the self_uri of this UpdateUser.
        The URI for this object

        :return: The self_uri of this UpdateUser.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this UpdateUser.
        The URI for this object

        :param self_uri: The self_uri of this UpdateUser.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ScimV2SchemaAttribute(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ScimV2SchemaAttribute - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'type': 'str',
            'sub_attributes': 'list[ScimV2SchemaAttribute]',
            'multi_valued': 'bool',
            'description': 'str',
            'required': 'bool',
            'canonical_values': 'list[str]',
            'case_exact': 'bool',
            'mutability': 'str',
            'returned': 'str',
            'uniqueness': 'str',
            'reference_types': 'list[str]'
        }

        self.attribute_map = {
            'name': 'name',
            'type': 'type',
            'sub_attributes': 'subAttributes',
            'multi_valued': 'multiValued',
            'description': 'description',
            'required': 'required',
            'canonical_values': 'canonicalValues',
            'case_exact': 'caseExact',
            'mutability': 'mutability',
            'returned': 'returned',
            'uniqueness': 'uniqueness',
            'reference_types': 'referenceTypes'
        }

        self._name = None
        self._type = None
        self._sub_attributes = None
        self._multi_valued = None
        self._description = None
        self._required = None
        self._canonical_values = None
        self._case_exact = None
        self._mutability = None
        self._returned = None
        self._uniqueness = None
        self._reference_types = None

    @property
    def name(self):
        """
        Gets the name of this ScimV2SchemaAttribute.
        The name of the attribute.

        :return: The name of this ScimV2SchemaAttribute.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ScimV2SchemaAttribute.
        The name of the attribute.

        :param name: The name of this ScimV2SchemaAttribute.
        :type: str
        """
        
        self._name = name

    @property
    def type(self):
        """
        Gets the type of this ScimV2SchemaAttribute.
        The data type of the attribute.

        :return: The type of this ScimV2SchemaAttribute.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ScimV2SchemaAttribute.
        The data type of the attribute.

        :param type: The type of this ScimV2SchemaAttribute.
        :type: str
        """
        allowed_values = ["STRING", "BOOLEAN", "DECIMAL", "INTEGER", "DATE_TIME", "REFERENCE", "COMPLEX"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def sub_attributes(self):
        """
        Gets the sub_attributes of this ScimV2SchemaAttribute.
        The list of subattributes for an attribute of the type \"complex\". Uses the same schema as \"attributes\".

        :return: The sub_attributes of this ScimV2SchemaAttribute.
        :rtype: list[ScimV2SchemaAttribute]
        """
        return self._sub_attributes

    @sub_attributes.setter
    def sub_attributes(self, sub_attributes):
        """
        Sets the sub_attributes of this ScimV2SchemaAttribute.
        The list of subattributes for an attribute of the type \"complex\". Uses the same schema as \"attributes\".

        :param sub_attributes: The sub_attributes of this ScimV2SchemaAttribute.
        :type: list[ScimV2SchemaAttribute]
        """
        
        self._sub_attributes = sub_attributes

    @property
    def multi_valued(self):
        """
        Gets the multi_valued of this ScimV2SchemaAttribute.
        Indicates whether an attribute contains multiple values.

        :return: The multi_valued of this ScimV2SchemaAttribute.
        :rtype: bool
        """
        return self._multi_valued

    @multi_valued.setter
    def multi_valued(self, multi_valued):
        """
        Sets the multi_valued of this ScimV2SchemaAttribute.
        Indicates whether an attribute contains multiple values.

        :param multi_valued: The multi_valued of this ScimV2SchemaAttribute.
        :type: bool
        """
        
        self._multi_valued = multi_valued

    @property
    def description(self):
        """
        Gets the description of this ScimV2SchemaAttribute.
        The description of the attribute.

        :return: The description of this ScimV2SchemaAttribute.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ScimV2SchemaAttribute.
        The description of the attribute.

        :param description: The description of this ScimV2SchemaAttribute.
        :type: str
        """
        
        self._description = description

    @property
    def required(self):
        """
        Gets the required of this ScimV2SchemaAttribute.
        Indicates whether an attribute is required.

        :return: The required of this ScimV2SchemaAttribute.
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """
        Sets the required of this ScimV2SchemaAttribute.
        Indicates whether an attribute is required.

        :param required: The required of this ScimV2SchemaAttribute.
        :type: bool
        """
        
        self._required = required

    @property
    def canonical_values(self):
        """
        Gets the canonical_values of this ScimV2SchemaAttribute.
        The list of standard values that service providers may use. Service providers may ignore unsupported values.

        :return: The canonical_values of this ScimV2SchemaAttribute.
        :rtype: list[str]
        """
        return self._canonical_values

    @canonical_values.setter
    def canonical_values(self, canonical_values):
        """
        Sets the canonical_values of this ScimV2SchemaAttribute.
        The list of standard values that service providers may use. Service providers may ignore unsupported values.

        :param canonical_values: The canonical_values of this ScimV2SchemaAttribute.
        :type: list[str]
        """
        
        self._canonical_values = canonical_values

    @property
    def case_exact(self):
        """
        Gets the case_exact of this ScimV2SchemaAttribute.
        Indicates whether a string attribute is case-sensitive. If set to \"true\", the server preserves case sensitivity. If set to \"false\", the server may change the case. The server also uses case sensitivity when evaluating filters. See section 3.4.2.2 \"Filtering\" in RFC 7644 for details.

        :return: The case_exact of this ScimV2SchemaAttribute.
        :rtype: bool
        """
        return self._case_exact

    @case_exact.setter
    def case_exact(self, case_exact):
        """
        Sets the case_exact of this ScimV2SchemaAttribute.
        Indicates whether a string attribute is case-sensitive. If set to \"true\", the server preserves case sensitivity. If set to \"false\", the server may change the case. The server also uses case sensitivity when evaluating filters. See section 3.4.2.2 \"Filtering\" in RFC 7644 for details.

        :param case_exact: The case_exact of this ScimV2SchemaAttribute.
        :type: bool
        """
        
        self._case_exact = case_exact

    @property
    def mutability(self):
        """
        Gets the mutability of this ScimV2SchemaAttribute.
        The circumstances under which an attribute can be defined or redefined. The default is \"readWrite\".

        :return: The mutability of this ScimV2SchemaAttribute.
        :rtype: str
        """
        return self._mutability

    @mutability.setter
    def mutability(self, mutability):
        """
        Sets the mutability of this ScimV2SchemaAttribute.
        The circumstances under which an attribute can be defined or redefined. The default is \"readWrite\".

        :param mutability: The mutability of this ScimV2SchemaAttribute.
        :type: str
        """
        allowed_values = ["readWrite", "readOnly", "immutable", "writeOnly"]
        if mutability.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for mutability -> " + mutability)
            self._mutability = "outdated_sdk_version"
        else:
            self._mutability = mutability

    @property
    def returned(self):
        """
        Gets the returned of this ScimV2SchemaAttribute.
        The circumstances under which an attribute and its values are returned in response to a GET, PUT, POST, or PATCH request.

        :return: The returned of this ScimV2SchemaAttribute.
        :rtype: str
        """
        return self._returned

    @returned.setter
    def returned(self, returned):
        """
        Sets the returned of this ScimV2SchemaAttribute.
        The circumstances under which an attribute and its values are returned in response to a GET, PUT, POST, or PATCH request.

        :param returned: The returned of this ScimV2SchemaAttribute.
        :type: str
        """
        allowed_values = ["ALWAYS", "NEVER", "DEFAULT", "REQUEST"]
        if returned.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for returned -> " + returned)
            self._returned = "outdated_sdk_version"
        else:
            self._returned = returned

    @property
    def uniqueness(self):
        """
        Gets the uniqueness of this ScimV2SchemaAttribute.
        The method by which the service provider enforces the uniqueness of an attribute value. A server can reject a value by returning the HTTP response code 400 (Bad Request). A client can enforce uniqueness to a greater degree than the server provider enforces. For example, a client could make a value unique even though the server has \"uniqueness\" set to \"none\".

        :return: The uniqueness of this ScimV2SchemaAttribute.
        :rtype: str
        """
        return self._uniqueness

    @uniqueness.setter
    def uniqueness(self, uniqueness):
        """
        Sets the uniqueness of this ScimV2SchemaAttribute.
        The method by which the service provider enforces the uniqueness of an attribute value. A server can reject a value by returning the HTTP response code 400 (Bad Request). A client can enforce uniqueness to a greater degree than the server provider enforces. For example, a client could make a value unique even though the server has \"uniqueness\" set to \"none\".

        :param uniqueness: The uniqueness of this ScimV2SchemaAttribute.
        :type: str
        """
        allowed_values = ["NONE", "SERVER", "GLOBAL"]
        if uniqueness.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for uniqueness -> " + uniqueness)
            self._uniqueness = "outdated_sdk_version"
        else:
            self._uniqueness = uniqueness

    @property
    def reference_types(self):
        """
        Gets the reference_types of this ScimV2SchemaAttribute.
        The list of SCIM resource types that may be referenced. Only applies when \"type\" is set to \"reference\".

        :return: The reference_types of this ScimV2SchemaAttribute.
        :rtype: list[str]
        """
        return self._reference_types

    @reference_types.setter
    def reference_types(self, reference_types):
        """
        Sets the reference_types of this ScimV2SchemaAttribute.
        The list of SCIM resource types that may be referenced. Only applies when \"type\" is set to \"reference\".

        :param reference_types: The reference_types of this ScimV2SchemaAttribute.
        :type: list[str]
        """
        
        self._reference_types = reference_types

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

